@@ -150,7 +150,7 @@ class BaseExperiment:
         Raises: 
 
             ValueError: When the dimension of the data is wrong. 
-            
+
         Returns:
 
             None
@@ -262,6 +262,7 @@ class BaseExperiment:
         
         del self.data_module
         self.data_module = None
+        data_module = None
         if isinstance(self.model, ConvNet):
             if len(self.X.shape) > 2:
                 data_module = initialize_datamodule(
@@ -329,6 +330,58 @@ class BaseExperiment:
                     random_state=self.random_state
                 )
 
+        elif isinstance(self.model, pl.LightningModule):
+            batch_size = 256 if torch.cuda.is_available() else 64
+            if self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
+                data_module = initialize_datamodule(
+                    batch_size=batch_size, 
+                    X=self.X.reshape(self.X.shape[0],-1), 
+                    y=self.y,
+                    X_val=self.X_val,
+                    y_val=self.y_val,
+                    X_test=self.X_test,
+                    y_test=self.y_test,
+                    test_size=self.test_size,
+                    random_state=self.random_state
+                )
+            elif self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
+                data_module = initialize_datamodule(
+                    batch_size=batch_size, 
+                    X=self.X.reshape(self.X.shape[0],-1), 
+                    y=self.y,
+                    X_val=self.X_val.reshape((self.X_val.shape[0], -1)),
+                    y_val=self.y_val,
+                    X_test=self.X_test,
+                    y_test=self.y_test,
+                    test_size=self.test_size,
+                    random_state=self.random_state
+                )
+            
+            elif self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
+                data_module = initialize_datamodule(
+                    batch_size=batch_size, 
+                    X=self.X.reshape(self.X.shape[0],-1), 
+                    y=self.y,
+                    X_val=self.X_val,
+                    y_val=self.y_val,
+                    X_test=self.X_test.reshape((self.X_test.shape[0], -1)),
+                    y_test=self.y_test,
+                    test_size=self.test_size,
+                    random_state=self.random_state
+                )
+                
+            elif self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
+                data_module = initialize_datamodule(
+                    batch_size=batch_size, 
+                    X=self.X.reshape(self.X.shape[0],-1), 
+                    y=self.y,
+                    X_val=self.X_val,
+                    y_val=self.y_val,
+                    X_test=self.X_test,
+                    y_test=self.y_test,
+                    test_size=self.test_size,
+                    random_state=self.random_state
+                )
         elif isinstance(self.model, BaseEstimator):
             if self.X_test is None and self.y_test is None:  
                 X_, X_test, y_, y_test = train_test_split(self.X, self.y, test_size=self.test_size, stratify=self.y)
