@@ -16,13 +16,20 @@ def split_data(
         y_test : Optional[Union["torch.Tensor", "np.ndarray", "pd.DataFrame"]] = None,
         random_state : int = 0
 ):
-    """
-    batch_size : Size of each batch.
-    X, y : Data and label for your experiment
-    
-    test_size : split ratio of the data.  (# train : # val : # test = 1-2* test_size : test_size : test_size) if (X_test, y_test) = (None, None)
-                                          (# train : # val = 1-test_size : test_size) if X_test and y_test are specified.
-    random_state : random_state in splitting the data.
+    r"""
+    Args:
+        X, y (torch.Tensor or np.ndarray or pd.DataFrame): Data and label for your experiment
+        
+        test_size : split ratio of the data. 
+            Default: ``1e-2``
+
+        random_state : random_state in splitting the data.
+            Default: ``0``
+
+    Returns:
+
+        tuple of `torch.Tensors`: The train/val/test data. 
+
     """
     if (X_test is None and y_test is not None) or (X_test is not None and y_test is None):
         raise ValueError("X_test and y_test should both be specified as a certain np.array object, or else all be NoneType objects.")
@@ -68,6 +75,8 @@ def split_data(
 
 
 class DataModule(pl.LightningDataModule):
+    r"""DataModule for experiments.   
+    """
     def __init__(
         self,
         batch_size : int, 
@@ -81,13 +90,6 @@ class DataModule(pl.LightningDataModule):
         random_state : int = 0
     ) -> None:
 
-        """
-        batch_size : Size of each batch.
-        X, y : Data and label for your experiment
-        X_test, y_test : Separate dataset for testing define this only if there is a pre-defined test set. (default = None)
-        test_size : split ratio of the data. (# train : # val : # test = 1-2* test_size : test_size : test_size)
-        random_state : random_state
-        """
         super(DataModule, self).__init__()
 
         self.X = X
