@@ -16,7 +16,7 @@ def column_or_1d(y):
     if (len(shape) == 1) or (len(shape) == 2 and shape[1] == 1):
         return torch.ravel(y)
     
-    raise ValueError("y should be a 1d tensor, got a tensor of shape {} instead.".format(shape))
+    raise ValueError(f"y should be a 1d tensor, got a tensor of shape {shape} instead.")
 
 class BCELossMetrics():
     def __init__(self):
